@@ -13,6 +13,7 @@ from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
 from plone.app.testing import SITE_OWNER_PASSWORD
 from plone.app.testing import TEST_USER_ID
+from plone.app.testing import TEST_USER_PASSWORD
 from plone.app.textfield.value import RichTextValue
 from plone.dexterity.utils import createContentInContainer
 from plone.locking.interfaces import ITTWLockable
@@ -250,7 +251,8 @@ class TestDocumentation(TestDocumentationBase):
         transaction.commit()
 
         response = self.api_session.post(
-            folder.absolute_url(), json={"@type": "Document", "title": "My Document"}
+            folder.absolute_url(),
+            json={"@type": "Document", "title": "My Document"},
         )
         save_request_and_response_for_docs("content_post", response)
 
@@ -413,7 +415,11 @@ class TestDocumentation(TestDocumentationBase):
         self.portal.invokeFactory("Folder", id="folder1", title="Folder 1")
         self.portal.folder1.invokeFactory("Folder", id="folder2", title="Folder 2")
         transaction.commit()
-        query = {"sort_on": "path", "path.query": "/plone/folder1", "path.depth": "1"}
+        query = {
+            "sort_on": "path",
+            "path.query": "/plone/folder1",
+            "path.depth": "1",
+        }
         response = self.api_session.get("/@search", params=query)
         save_request_and_response_for_docs("search_options", response)
 
@@ -434,7 +440,10 @@ class TestDocumentation(TestDocumentationBase):
     def test_documentation_search_metadata_fields(self):
         self.portal.invokeFactory("Document", id="doc1", title="Lorem Ipsum")
         transaction.commit()
-        query = {"SearchableText": "lorem", "metadata_fields": ["modified", "created"]}
+        query = {
+            "SearchableText": "lorem",
+            "metadata_fields": ["modified", "created"],
+        }
         response = self.api_session.get("/@search", params=query)
         save_request_and_response_for_docs("search_metadata_fields", response)
 
@@ -477,7 +486,8 @@ class TestDocumentation(TestDocumentationBase):
 
     def test_documentation_registry_update(self):
         response = self.api_session.patch(
-            "/@registry/", json={"plone.app.querystring.field.path.title": "Value"}
+            "/@registry/",
+            json={"plone.app.querystring.field.path.title": "Value"},
         )
         save_request_and_response_for_docs("registry_update", response)
 
@@ -761,7 +771,9 @@ class TestDocumentation(TestDocumentationBase):
         ]
         for i in range(7):
             folder.invokeFactory(
-                "Document", id="doc-%s" % str(i + 1), title="Document %s" % str(i + 1)
+                "Document",
+                id="doc-%s" % str(i + 1),
+                title="Document %s" % str(i + 1),
             )
         transaction.commit()
 
@@ -839,7 +851,9 @@ class TestDocumentation(TestDocumentationBase):
             "location": "Cambridge, MA",
         }
         api.user.create(
-            email="noam.chomsky@example.com", username="noam", properties=properties
+            email="noam.chomsky@example.com",
+            username="noam",
+            properties=properties,
         )
         transaction.commit()
         response = self.api_session.get("@users/noam")
@@ -855,7 +869,9 @@ class TestDocumentation(TestDocumentationBase):
             "location": "Cambridge, MA",
         }
         api.user.create(
-            email="noam.chomsky@example.com", username="noam", properties=properties
+            email="noam.chomsky@example.com",
+            username="noam",
+            properties=properties,
         )
         transaction.commit()
 
@@ -878,14 +894,14 @@ class TestDocumentation(TestDocumentationBase):
         api.user.create(
             email="noam.chomsky@example.com",
             username="noam",
-            password="secret",
+            password=TEST_USER_PASSWORD,
             properties=properties,
         )
 
         api.user.create(
             email="noam.chomsky@example.com",
             username="noam-fake",
-            password="secret",
+            password=TEST_USER_PASSWORD,
             properties=properties,
         )
 
@@ -893,7 +909,7 @@ class TestDocumentation(TestDocumentationBase):
 
         logged_out_api_session = RelativeSession(self.portal_url, test=self)
         logged_out_api_session.headers.update({"Accept": "application/json"})
-        logged_out_api_session.auth = ("noam-fake", "secret")
+        logged_out_api_session.auth = ("noam-fake", TEST_USER_PASSWORD)
 
         response = logged_out_api_session.get("@users/noam")
         save_request_and_response_for_docs("users_unauthorized_get", response)
@@ -911,14 +927,14 @@ class TestDocumentation(TestDocumentationBase):
         api.user.create(
             email="noam.chomsky@example.com",
             username="noam",
-            password="secret",
+            password=TEST_USER_PASSWORD,
             properties=properties,
         )
         transaction.commit()
 
         logged_out_api_session = RelativeSession(self.portal_url, test=self)
         logged_out_api_session.headers.update({"Accept": "application/json"})
-        logged_out_api_session.auth = ("noam", "secret")
+        logged_out_api_session.auth = ("noam", TEST_USER_PASSWORD)
         response = logged_out_api_session.get("@users/noam")
         save_request_and_response_for_docs("users_authorized_get", response)
         logged_out_api_session.close()
@@ -931,7 +947,9 @@ class TestDocumentation(TestDocumentationBase):
             "location": "Cambridge, MA",
         }
         api.user.create(
-            email="noam.chomsky@example.com", username="noam", properties=properties
+            email="noam.chomsky@example.com",
+            username="noam",
+            properties=properties,
         )
         api.group.add_user(groupname="Reviewers", username="noam")
         transaction.commit()
@@ -1002,7 +1020,9 @@ class TestDocumentation(TestDocumentationBase):
             "location": "Cambridge, MA",
         }
         api.user.create(
-            email="noam.chomsky@example.com", username="noam", properties=properties
+            email="noam.chomsky@example.com",
+            username="noam",
+            properties=properties,
         )
         transaction.commit()
 
@@ -1060,7 +1080,9 @@ class TestDocumentation(TestDocumentationBase):
             "location": "Cambridge, MA",
         }
         api.user.create(
-            email="noam.chomsky@example.com", username="noam", properties=properties
+            email="noam.chomsky@example.com",
+            username="noam",
+            properties=properties,
         )
         transaction.commit()
 
@@ -1231,7 +1253,10 @@ class TestDocumentation(TestDocumentationBase):
         )
         createContentInContainer(folder, "Folder", id="subfolder2", title="SubFolder 2")
         thirdlevelfolder = createContentInContainer(
-            subfolder1, "Folder", id="thirdlevelfolder", title="Third Level Folder"
+            subfolder1,
+            "Folder",
+            id="thirdlevelfolder",
+            title="Third Level Folder",
         )
         createContentInContainer(
             thirdlevelfolder,
@@ -1260,7 +1285,10 @@ class TestDocumentation(TestDocumentationBase):
         )
         createContentInContainer(folder, "Folder", id="subfolder2", title="SubFolder 2")
         thirdlevelfolder = createContentInContainer(
-            subfolder1, "Folder", id="thirdlevelfolder", title="Third Level Folder"
+            subfolder1,
+            "Folder",
+            id="thirdlevelfolder",
+            title="Third Level Folder",
         )
         createContentInContainer(
             thirdlevelfolder,
@@ -1307,7 +1335,12 @@ class TestDocumentation(TestDocumentationBase):
 
         response = self.api_session.post(
             "/@copy",
-            json={"source": [self.document.absolute_url(), newsitem.absolute_url()]},
+            json={
+                "source": [
+                    self.document.absolute_url(),
+                    newsitem.absolute_url(),
+                ]
+            },
         )
         save_request_and_response_for_docs("copy_multiple", response)
 
@@ -1352,7 +1385,10 @@ class TestDocumentation(TestDocumentationBase):
 
     def test_documentation_sources_get(self):
         api.content.create(
-            container=self.portal, id="doc", type="DXTestDocument", title="DX Document"
+            container=self.portal,
+            id="doc",
+            type="DXTestDocument",
+            title="DX Document",
         )
         transaction.commit()
         response = self.api_session.get("/doc/@sources/test_choice_with_source")
@@ -1544,7 +1580,8 @@ class TestDocumentation(TestDocumentationBase):
         # Replace dynamic lock token with a static one
         response._content = re.sub(
             b'"token": "[^"]+"',
-            b'"token": "0.684672730996-0.25195226375-00105A989226:1477076400.000"',  # noqa
+            b'"token":'
+            b' "0.684672730996-0.25195226375-00105A989226:1477076400.000"',  # noqa
             response.content,
         )
         save_request_and_response_for_docs("lock", response)
@@ -1557,7 +1594,8 @@ class TestDocumentation(TestDocumentationBase):
         # Replace dynamic lock token with a static one
         response._content = re.sub(
             b'"token": "[^"]+"',
-            b'"token": "0.684672730996-0.25195226375-00105A989226:1477076400.000"',  # noqa
+            b'"token":'
+            b' "0.684672730996-0.25195226375-00105A989226:1477076400.000"',  # noqa
             response.content,
         )
         save_request_and_response_for_docs("lock_nonstealable_timeout", response)
@@ -1583,7 +1621,8 @@ class TestDocumentation(TestDocumentationBase):
         # Replace dynamic lock token with a static one
         response._content = re.sub(
             b'"token": "[^"]+"',
-            b'"token": "0.684672730996-0.25195226375-00105A989226:1477076400.000"',  # noqa
+            b'"token":'
+            b' "0.684672730996-0.25195226375-00105A989226:1477076400.000"',  # noqa
             response.content,
         )
         save_request_and_response_for_docs("refresh_lock", response)
@@ -1840,6 +1879,137 @@ class TestCommenting(TestDocumentationBase):
         response = self.api_session.get("/front-page?expand=breadcrumbs,workflow")
         save_request_and_response_for_docs("expansion", response)
 
+    def test_aliases_add(self):
+        # Add 3 aliases
+        url = f"{self.document.absolute_url()}/@aliases"
+        payload = {
+            "items": [
+                {"path": "/new-alias"},
+                {"path": "/old-alias"},
+                {"path": "/final-alias"},
+            ]
+        }
+        response = self.api_session.post(url, json=payload)
+        save_request_and_response_for_docs("aliases_add", response)
+
+    def test_aliases_delete(self):
+        # Delete 1 alias
+        url = f"{self.document.absolute_url()}/@aliases"
+        payload = {
+            "items": [
+                {"path": "/new-alias"},
+                {"path": "/old-alias"},
+                {"path": "/final-alias"},
+            ]
+        }
+        response = self.api_session.post(url, json=payload)
+
+        payload = {"items": [{"path": "/old-alias"}]}
+        response = self.api_session.delete(url, json=payload)
+
+        save_request_and_response_for_docs("aliases_delete", response)
+
+    def test_aliases_get(self):
+        # Get aliases
+        url = f"{self.document.absolute_url()}/@aliases"
+
+        payload = {"items": "/simple-alias"}
+        response = self.api_session.post(url, json=payload)
+
+        response = self.api_session.get(url)
+        save_request_and_response_for_docs("aliases_get", response)
+
+    def test_aliases_root_add(self):
+        # Add 2 aliases
+        url = f"{self.portal.absolute_url()}/@aliases"
+        payload = {
+            "items": [
+                {
+                    "path": "/old-page",
+                    "redirect-to": "/front-page",
+                    "datetime": "2022-05-05",
+                },
+                {
+                    "path": "/fizzbuzz",
+                    "redirect-to": "/front-page",
+                    "datetime": "2022-05-05",
+                },
+            ]
+        }
+
+        response = self.api_session.post(url, json=payload)
+        save_request_and_response_for_docs("aliases_root_add", response)
+
+    def test_aliases_root_delete(self):
+        # Delete 1 alias
+        url = f"{self.portal.absolute_url()}/@aliases"
+        payload = {
+            "items": [
+                {
+                    "path": "/old-page",
+                    "redirect-to": "/front-page",
+                },
+                {
+                    "path": "/fizzbuzz",
+                    "redirect-to": "/front-page",
+                },
+            ]
+        }
+        response = self.api_session.post(url, json=payload)
+
+        payload = {"items": [{"path": "/old-page"}]}
+        response = self.api_session.delete(url, json=payload)
+
+        save_request_and_response_for_docs("aliases_root_delete", response)
+
+    def test_aliases_root_get(self):
+        # Get aliases
+        url = f"{self.portal.absolute_url()}/@aliases"
+        query = ""
+
+        payload = {
+            "items": [
+                {
+                    "path": "/old-page",
+                    "redirect-to": "/front-page",
+                    "datetime": "2022-05-05",
+                },
+                {
+                    "path": "/fizzbuzz",
+                    "redirect-to": "/front-page",
+                    "datetime": "2022-05-05",
+                },
+            ]
+        }
+        response = self.api_session.post(url, json=payload)
+
+        response = self.api_session.get(url + query)
+        save_request_and_response_for_docs("aliases_root_get", response)
+
+    def test_aliases_root_filter(self):
+        # Get aliases
+        url = f"{self.portal.absolute_url()}/@aliases"
+        query = "?q=/fizzbuzz"
+
+        payload = {
+            "items": [
+                {
+                    "path": "/old-page",
+                    "redirect-to": "/front-page",
+                    "datetime": "2022-05-05",
+                },
+                {
+                    "path": "/fizzbuzz",
+                    "redirect-to": "/front-page",
+                    "datetime": "2022-05-05",
+                },
+            ]
+        }
+        response = self.api_session.post(url, json=payload)
+
+        response = self.api_session.get(url + query)
+        save_request_and_response_for_docs("aliases_root_filter", response)
+
 
 class TestControlPanelDocumentation(TestDocumentationBase):
 
@@ -2085,3 +2255,8 @@ class TestIterateDocumentation(TestDocumentationBase):
         save_request_and_response_for_docs(
             "vocabularies_get_filtered_by_token_list", response
         )
+
+    def test_documentation_schema_user(self):
+        response = self.api_session.get("/@userschema")
+
+        save_request_and_response_for_docs("userschema", response)
